#
# spec file for package sccache
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define configdir %{_sysconfdir}/%{name}

Name:           sccache
Version:        0.8.1~31
Release:        1.1
Summary:        A compiler caching tool for Rust, C and C++ with optional cloud storage
License:        (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR CC0-1.0) AND ((Apache-2.0 AND BSD-2-Clause) OR MIT) AND (Apache-2.0 OR MIT OR BSD-2-Clause) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND ISC AND MIT
Group:          Development/Languages/Rust
URL:            https://github.com/mozilla/%{name}
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source10:       sccache-dist-builder.service
Source11:       sccache-dist-scheduler.service
Source12:       builder.conf
Source13:       scheduler.conf
Source14:       client.example
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(openssl) >= 3
Requires:       bubblewrap

%description
Sccache is a ccache-like tool. It is used as a compiler wrapper and
avoids compilation when possible, storing a cache in a remote storage
using the Amazon Simple Cloud Storage Service (S3) API, Redis or
the Google Cloud Storage (GCS) API.

%prep
%setup -q
%setup -qa1

# Remove exec bits to prevent an issue in fedora shebang checking
find vendor -type f -name \*.rs -exec chmod -x '{}' \;

%build
%ifarch x86_64
# 'dist-server' available only on x86_64 so far - https://github.com/mozilla/sccache/issues/656
features="azure,s3,redis,dist-server,dist-client,concurrent-cache"
%else
%ifarch aarch64
features="azure,s3,redis,concurrent-cache"
%else
# Most other arches have issues (especially with ring). Use FS cache only
features="concurrent-cache"
%endif
%endif

%{cargo_build} --no-default-features --features=$features

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -D -d -m 0755 %{buildroot}%{_unitdir}
install -D -d -m 0755 %{buildroot}%{configdir}

install -m 0755 %{_builddir}/%{name}-%{version}/target/release/sccache %{buildroot}%{_bindir}/sccache
%ifarch x86_64
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/sccache-dist %{buildroot}%{_bindir}/sccache-dist
%endif

%ifarch x86_64
install -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}/sccache-dist-builder.service
install -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/sccache-dist-scheduler.service
%endif
install -m 0644 %{SOURCE12} %{buildroot}%{configdir}/builder.conf
install -m 0644 %{SOURCE13} %{buildroot}%{configdir}/scheduler.conf
install -m 0644 %{SOURCE14} %{buildroot}%{configdir}/client.example

%ifarch x86_64
%pre
%service_add_pre sccache-dist-builder.service
%service_add_pre sccache-dist-scheduler.service

%post
%service_add_post sccache-dist-builder.service
%service_add_post sccache-dist-scheduler.service

%preun
%service_del_preun sccache-dist-builder.service
%service_del_preun sccache-dist-scheduler.service

%postun
%service_del_postun sccache-dist-builder.service
%service_del_postun sccache-dist-scheduler.service
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/sccache
%ifarch x86_64
%{_bindir}/sccache-dist

%{_unitdir}/sccache-dist-builder.service
%{_unitdir}/sccache-dist-scheduler.service
%endif

%dir %{configdir}
%config(noreplace) %{configdir}/scheduler.conf
%config(noreplace) %{configdir}/builder.conf
%config(noreplace) %{configdir}/client.example

%changelog
* Tue Sep 10 2024 william.brown@suse.com
- explicitly depend on cargo to pull in latest compiler revision
- Update to version 0.8.1~31:
  * Add experimental concurrent cache support
  * build(deps): bump quinn-proto from 0.11.3 to 0.11.8 (#2254)
  * build(deps): bump which from 6.0.0 to 6.0.3 (#2252)
  * Disable "warnings as errors" flag for CL preprocessing (#2251)
  * Add windows arm64 to the CI (#2243)
  * build(deps): bump log from 0.4.20 to 0.4.22 (#2218)
  * feat: Bump opendal to 0.48.0 (#2240)
  * deps: update winapi-util (#2236)
  * refactor: use windows-sys instead of winapi (#2233)
  * build(deps): bump vmactions/freebsd-vm from 1.0.7 to 1.0.8 (#2219)
  * Add cache hit percentage to stats (#2211)
  * Add custom zstd compression level (#2199)
  * Remove the heapsize feature
  * Add lost feature status
  * Update OpenDAL for fixing #2220
  * build(deps): bump reqwest from 0.12.4 to 0.12.5 (#2215)
  * build(deps): bump uuid from 1.7.0 to 1.9.0 (#2213)
  * Update CI version of macOS
  * build(deps): bump zstd from 0.13.0 to 0.13.1
  * build(deps): bump async-trait from 0.1.77 to 0.1.80
  * build(deps): bump anyhow from 1.0.81 to 1.0.86
  * Format toml
  * refactor: Bump OpenDAL to 0.47
  * Remove ref_env
  * Fix clippy
  * Fix clippy
  * refactor: Bump MSRV to 1.75 for async in trait
  * Log when preprocessor cache cannot be used (#2197)
  * Avoid keeping lock while writing to disk cache (#2193)
  * Disable preprocessor cache with -MD and friends (#2195)
* Wed Sep  4 2024 William Brown <william.brown@suse.com>
- bsc#1229955 - RUSTSEC-2024-0006 - rust-shlex: Multiple issues involving quote API
* Fri May 31 2024 william.brown@suse.com
- Update to version 0.8.1~2:
  * Add experimental concurrent cache support
  * deps: bump libc from 0.2.153 to 0.2.155 (#2188)
  * sccache: prepare new release (#2179)
  * build(deps): bump bytes from 1.5.0 to 1.6.0 (#2176)
  * build(deps): bump encoding_rs from 0.8.33 to 0.8.34 (#2178)
  * build(deps): bump semver from 1.0.22 to 1.0.23 (#2177)
  * build(deps): bump tempfile from 3.9.0 to 3.10.1 (#2175)
  * build(deps): bump time from 0.3.31 to 0.3.36 (#2184)
  * Make preprocessor cache methods async (#2182)
  * Make recent versions of clippy happy (#2181)
  * Allow SCCACHE_CACHE_SIZE values without a unit (#2183)
  * Disable preprocessor cache when doing distributed compilation (#2173)
  * build(deps): bump jobserver from 0.1.28 to 0.1.31 (#2166)
  * build(deps): bump tokio from 1.35.1 to 1.37.0 (#2165)
  * build(deps): bump http-body-util from 0.1.0 to 0.1.1 (#2167)
  * build(deps): bump serde from 1.0.199 to 1.0.201 (#2171)
  * build(deps): bump serde from 1.0.195 to 1.0.199 (#2162)
  * build(deps): bump semver from 1.0.21 to 1.0.22 (#2109)
  * build(deps): bump nix from 0.27.1 to 0.28.0 (#2108)
  * build(deps): bump mio from 0.8.10 to 0.8.11 (#2128)
  * build(deps): bump h2 from 0.3.24 to 0.3.26 (#2144)
  * msvc: passthrough argument -Qpar- (#1834)
  * build(deps): bump rustls from 0.21.10 to 0.21.11 (#2151)
  * build(deps): bump serial_test from 2.0.0 to 3.1.0 (#2158)
  * Add required winapi features (#2160)
* Tue Apr 23 2024 william.brown@suse.com
- bsc#1223238 - CVE-2024-32650 - Infinite loop in
    rustls::conn::ConnectionCommon:complete_io()
- Update to version 0.8.0~3
  * Add experimental concurrent cache support
  * README: Remove duplicated info about openssl vendoring (#2157)
  * Fix the README working (Closes: #2154) (#2156)
  * prepare version 0.8.0 (#2153)
  * build(deps): bump vmactions/freebsd-vm from 1.0.6 to 1.0.7 (#2147)
  * Set User Agent Header for S3 Requests (#2137)
  * build(deps): bump anyhow from 1.0.79 to 1.0.81 (#2135)
  * Include server_startup_timeout_ms in config docs (#2134)
  * build(deps): bump walkdir from 2.4.0 to 2.5.0 (#2127)
  * package cargo.toml (#2124)
  * feat: initial support for Clang HIP (#2045)
  * fix a typo
  * build(deps): bump openssl from 0.10.62 to 0.10.64 (#2106)
  * build(deps): bump serde_json from 1.0.111 to 1.0.114 (#2112)
  * feat: Add Memcached authentication (#2117)
  * chore: use what we really need from `opendal` (#2118)
  * build(deps): Upgrade OpenDAL to the latest version (#2114)
  * feat: Rewrite Redis environment variables API (#2116)
  * Remove unused code warnings from Windows build (#2119)
  * Fix AArch64 build with musl (#2120)
  * feat: Add support to Redis cluster mode (#2113)
  * build(deps): bump codecov/codecov-action from 3 to 4 (#2078)
  * rustc driver detection - includes #1897 (#2085)
  * Disable tests when the feature is disabled
  * allow the compilation of sccache without any features (only local build)
  * build(deps): bump base64 from 0.21.6 to 0.21.7
  * build(deps): bump assert_cmd from 2.0.12 to 2.0.13
  * chore: Unify env bool processing (#2103)
  * Add different key prefix to the test
  * New memcached env vars were implemented
  * Simplify one match
  * Add expiration time parsing for the Redis
  * Unify sccache _KEY_PREFIX docs & processing
  * build(deps): bump opendal from 0.44.2 to 0.45.0 (#2086)
  * build(deps): bump hyper-util from 0.1.2 to 0.1.3 (#2099)
  * build(deps): bump is-terminal from 0.4.10 to 0.4.12 (#2097)
  * build(deps): bump toml from 0.8.8 to 0.8.10 (#2096)
  * build(deps): bump reqsign from 0.14.6 to 0.14.7 (#2098)
  * build(deps): bump memmap2 from 0.9.3 to 0.9.4 (#2089)
  * Add generic read-only storage mode for a storage that fails the write check (#2091)
  * build(deps): bump libc from 0.2.152 to 0.2.153 (#2087)
  * build(deps): bump jobserver from 0.1.27 to 0.1.28 (#2088)
  * build(deps): bump uuid from 1.6.1 to 1.7.0 (#2066)
  * feat: Add possibility to configure key prefix (Redis, MemCached) (#2084)
  * build(deps): bump env_logger from 0.10.1 to 0.10.2 (#2064)
  * build(deps): bump regex from 1.10.2 to 1.10.3 (#2063)
  * build(deps): bump which from 5.0.0 to 6.0.0 (#2051)
  * build(deps): bump chrono from 0.4.31 to 0.4.33 (#2065)
  * build(deps): bump vmactions/freebsd-vm from 1.0.5 to 1.0.6 (#2067)
  * More Redis URLs typos fix (#2081)
  * upgrade to version 0.7.7 (#2080)
  * [commands::run_server_process]: fix race condition (#2077)
  * chore: update S3 docs on region (#2079)
  * Improve Redis docs (#2072)
  * Note allowed --emit metadata in rust doc (#2075)
  * github action: run on native m1 (#2068)
  * build(deps): bump h2 from 0.3.22 to 0.3.24 (#2047)
  * build(deps): bump predicates from 3.0.3 to 3.1.0 (#2052)
  * Implement read-only local cache (#2048)
  * feat(tree-wide): migrate to Hyper 1.x
  * Update OpenDAL to 0.44.2 (#2060)
  * Avoid spawning a new server for --show-stats
  * Always fill disk cache max size accurately
  * add default ttl of 0 to fix breaking change (#2058)
  * build(deps): bump clap from 4.3.24 to 4.4.18 (#2050)
  * Make --zero-stats just show a message that it's done its job (#2055)
  * ci: Bump MSRV to 1.70.0 (#2054)
* Tue Jan 23 2024 william.brown@suse.com
- Update to version 0.7.5~9:
  * Add experimental concurrent cache support
  * feat(cache/oss): add support for oss (#2046)
  * Improve of the description
  * fix(src/compiler/c): take common_args into account during preprocessor hashing (#2039)
  * Add support for symlinks in toolchains. (#2030)
  * Fix docs on integrating sccache with MSVC when cmake >= 3.25 (#2031)
  * refactor: Remove all dependences on ring 0.16 (#2036)
  * feat(redis): add support for ttl, fix #1666 (#2027)
  * Prepare version 0.7.5
  * fix(src/compiler/msvc): add a new encode/decode test ...
  * fix(src/compiler/msvc): use pre-encoded UTF-16 data ...
  * chore(src/compiler/msvc): replace rust-encoding with encoding-rs ...
  * build(deps): bump serde from 1.0.194 to 1.0.195 (#2017)
  * build(deps): bump libc from 0.2.151 to 0.2.152 (#2019)
  * build(deps): bump base64 from 0.21.5 to 0.21.6 (#2016)
  * build(deps): bump opendal from 0.44.0 to 0.44.1 (#2014)
  * feat(snap): add sccache-dist binary to the Snap
  * chore(snap): adapt the configurations to Snapcraft 8.0
  * build(deps): bump actions/github-script from 6 to 7
  * build(deps): bump actions/download-artifact from 3 to 4
  * build(deps): bump actions/upload-artifact from 3 to 4
  * chore(cargo): update dependencies to compatible versions (#2009)
  * build(deps): bump tar from 0.4.38 to 0.4.40
  * build(deps): bump test-case from 3.2.1 to 3.3.1
  * Clone repo in ci
  * Fix typo
  * Add ci feature check
  * Expand cfg for operator storage impl
  * Add i686 and fix armv7
  * Fix typo in target
  * Use container for arm build
  * Versionbump opendal 0.41.0 -> 0.43.0 (#1992)
  * build(deps): bump toml from 0.8.6 to 0.8.8
  * build(deps): bump vmactions/freebsd-vm from 1.0.4 to 1.0.5
  * build(deps): bump vmactions/freebsd-vm from 1.0.2 to 1.0.4
  * build(deps): bump nix from 0.26.2 to 0.26.4
* Tue Dec  5 2023 william.brown@suse.com
- Update to version 0.7.4~3:
  * Add experimental concurrent cache support
  * Bump freebsd-vm action to v1.0.2 & use ubuntu (#1994)
  * build(deps): bump serde from 1.0.190 to 1.0.193
  * Prepare version 0.7.4
  * Activate direct mode when e.g. SCCACHE_DIR is set.
  * Remove some unnecessary clones
  * Only activate direct mode by default for local
  * Catch panics in the server and transmit them as errors to the client.
  * Remove uses of Lazy<Mutex<T>>
  * Add support for `--` on clang/clang-cl command-line
  * Fix test_parse_arguments_multiarch_cache_disabled
  * Fix some possible out-of-bound accesses in process_preprocesed_{file,line}
  * prepare version 0.7.3
  * Revert "Activate preprocessor cache mode by default"
* Wed Nov 15 2023 william.brown@suse.com
- Update to version 0.7.2~0:
  * Add experimental concurrent cache support
  * Fix some typos
  * prepare version 0.7.2
  * Don't pass wd4668 to clang-cl
  * build(deps): bump zstd from 0.12.4 to 0.13.0
  * build(deps): bump bytes from 1.4.0 to 1.5.0
  * build(deps): bump base64 from 0.21.3 to 0.21.5
  * build(deps): bump jobserver from 0.1.26 to 0.1.27
  * build(deps): bump semver from 1.0.17 to 1.0.20
  * Activate preprocessor cache mode by default
  * Fix input file times in end-to-end tests
  * Appease the TOML formatter
  * Parametrize relevant tests with preprocessor cache
  * Add dummy input file to all tests that call the preprocessor
  * Improve context for open error when opening the input file
  * Comment out the logging setup in the test harness
  * Fix location of the local daemon log in the test harness
  * Fail early if the local daemon doesn't start properly during tests
  * Fix off-by-one in line number replacement code
  * prepare version 0.7.1
  * When fails to connect, show the error
  * build(deps): bump directories from 5.0.0 to 5.0.1
  * build(deps): bump toml from 0.7.6 to 0.8.6
  * build(deps): bump byteorder from 1.4.3 to 1.5.0
  * add a pre-commit conf
  * build(deps): bump assert_cmd from 2.0.11 to 2.0.12
  * build(deps): bump hyper from 0.14.25 to 0.14.27
  * build(deps): bump blake3 from 1.3.3 to 1.5.0
  * build(deps): bump filetime from 0.2.21 to 0.2.22
  * Cosmetic: add some spaces to separate blocks
  * --show-stats should show if we are using direct access/mode
  * add a check to fail quickly if SCCACHE_DIRECT is set but no directory info
  * Add a suggestion in case of error message
  * Allow using preprocessor mode from env without a disk config
  * direct access: adjust the doc (#1935)
  * Document how to set the direct access (#1936)
  * update to libc 0.2.149 (#1933)
  * build(deps): bump regex from 1.7.3 to 1.8.4 (#1794)
  * build(deps): bump num_cpus from 1.15.0 to 1.16.0
  * build(deps): bump assert_cmd from 2.0.10 to 2.0.11
  * build(deps): bump once_cell from 1.17.1 to 1.18.0
  * build(deps): bump walkdir from 2.3.3 to 2.4.0
  * build(deps): bump serde from 1.0.159 to 1.0.190
  * build(deps): bump syslog from 6.0.1 to 6.1.0
  * build(deps): bump flate2 from 1.0.26 to 1.0.28
  * build(deps): bump rouille from 3.6.1 to 3.6.2
  * build(deps): bump zstd from 0.12.3+zstd.1.5.2 to 0.12.4
  * prepare release 0.7.0
* Tue Oct 31 2023 william.brown@suse.com
- Update to version 0.6.0:
  * Add experimental concurrent cache support
  * workflow(ci): fix musl-tools:arm64 installation
  * workflows(ci): label each architecture's musl-tools installation
  * Revert "Disable aarch64-unknown-linux-musl"
  * Disable direct mode if `-Wp,*` is present
  * Rename `PreprocessorCacheEntry::write` to `serialize_to`
  * Sort include files before saving them
  * Simplify logic around time macros
  * Add entry about preprocessor caching to `Caching.md`
  * Address naming issues
  * Split up preprocessor processing
  * Don't use direct mode if `-Xpreprocessor` is used
  * Only emit lines in preprocessor output if in direct mode
  * Add docs for direct mode
  * Add commands to read the direct mode manifests
  * Introduce preprocessor caching (aka direct mode)
  * Add utils to scan for C time macros while hashing
  * Add timestamp-related utils
  * Make path encoding/decoding available as a util
  * install the hub package to publish the release
  * build(deps): bump tokio-util from 0.7.7 to 0.7.9
  * build(deps): bump memmap2 from 0.6.2 to 0.9.0
  * build(deps): bump async-trait from 0.1.68 to 0.1.74
  * build(deps): bump toml from 0.7.3 to 0.7.6
  * build(deps): bump base64 from 0.21.0 to 0.21.3
  * sccache 0.6.0
  * Fix typo in the doc
  * feat(s3): add server side encryption
  * Disable aarch64-unknown-linux-musl
  * clippy: remove the clippy suggestion Maybe the source of perf issue:  https://github.com/mozilla/sccache/issues/1910
  * build(deps): bump rustix from 0.36.15 to 0.36.16
  * Correct issues found by CI
  * Add `show-adv-stats` flag which shows per compiler hits/misses
  * Also update rust in snap
  * Fix more clippy warning - without autofix
  * Fix some clippy warnings
  * bump rust-version to 1.67 (was 1.65)
  * tests/system.rs Now correctly identifies apple clang (#1905)
  * sccache now tracks compiler hits/misses on a per language basis. (#1895)
  * Update opendal to 0.40.0
  * Bring back redis-over-tls (rediss) support
  * build(deps): bump webpki from 0.22.0 to 0.22.2
  * Fix a couple of typos (#1898)
  * Add clang as a supported cuda compiler
  * Add nvhpc ( nvc, nvc++ ) to the set of supported compilers
  * Address feedback of code-review.
  * Correct style issues found by clippy
  * Support nvc as the host compiler for nvcc
  * compiler: Support detecting compilers with pre-amble in -E
  * Support msvc as the host compiler for nvcc
  * nvcc: Support option files
  * Add cache hit/miss test for cuda compilation
  * services/gcs: Fix typo in to_scope (#1890)
  * chore: Bump OpenDAL to v0.40.0 (#1885)
  * Add MacPorts as a new installation method (#1881)
  * sccache fails to build on non x86_64/aarch64 arches (#1866)
  * update doc for cmake 3.25 on windows (#1873)
  * Add nvcc cubin,fatbin,optix-ir compilation mode support (#1872)
  * Update FreeBSD CI to 13.2-RELEASE (#1879)
  * Fix detection of clang version and v14+ unit tests (#1878)
  * build(deps): bump actions/checkout from 3 to 4
  * build(deps): bump semver from 1.0.16 to 1.0.17
  * build(deps): bump anyhow from 1.0.70 to 1.0.71
  * Properly propagate cache write errors
  * Log hash key at debug level instead of trace
  * nvcc: Support -Werror with argument
  * Bump proc-macro2 from 1.0.47 to 1.0.63
* Fri Sep 22 2023 william.brown@suse.com
- Update to version 0.5.4~2:
  * sccache fails to build on non x86_64/aarch64 arches
* Wed Aug 16 2023 William Brown <william.brown@suse.com>
- Update to use openssl 3
* Wed Jun 28 2023 william.brown@suse.com
- Update to version 0.5.4~1:
  * Add experimental concurrent cache support
  * Fix the version detection in the release script
  * build(deps): bump filetime from 0.2.20 to 0.2.21
  * build(deps): bump openssl from 0.10.49 to 0.10.55
  * cargo fmt
  * Fix cache read timing
  * prepare a new upstream release
  * build(deps): bump is-terminal from 0.4.5 to 0.4.7
  * build(deps): bump predicates from 3.0.2 to 3.0.3
  * build(deps): bump uuid from 1.3.1 to 1.3.3
  * Fix failing lint CI
  * Refactor out duplicated code
  * Add PCH tests
  * Properly implement PCH
  * Blacklist C++ PCHs
  * build(deps): bump log from 0.4.17 to 0.4.19
  * build(deps): bump chrono from 0.4.24 to 0.4.26
  * Revert "fix: wrong SCCACHE_S3_USE_SSL value parse (#1804)" (#1805)
  * fix: wrong SCCACHE_S3_USE_SSL value parse (#1804)
  * fix: Don't call EC2 Metadata and allow anonymouse if no cred (#1800)
  * feat: Bump OpenDAL to 0.37.0
  * Avoid new actions
  * Add workflow to prevent regress
  * chore: Make sure Cargo.toml is formatted
* Tue Jun  6 2023 william.brown@suse.com
- Update to version 0.5.3~2:
  * Add experimental concurrent cache support
  * build(deps): bump tokio from 1.28.0 to 1.28.2
  * version 0.5.3
  * Update Cargo.toml
  * Try revert opendal
  * version 0.5.2
* Sat Jun  3 2023 william.brown@suse.com
- Update to version 0.5.1~14:
  * Add experimental concurrent cache support
  * build(deps): bump openssl from 0.10.48 to 0.10.49
  * README: Add --locked to the cargo install
  * build(deps): bump serde from 1.0.155 to 1.0.159
  * build(deps): bump walkdir from 2.3.2 to 2.3.3
  * Disable C4668 during preprocessing for MSVC
  * Add integration test for MSVC preprocessing bug
  * Ignore C4668 when preprocessing MSVC
  * build(deps): bump hyper from 0.14.24 to 0.14.25
  * build(deps): bump flate2 from 1.0.25 to 1.0.26
  * Update ci.yml
  * Attempt to fix arm64 builds
  * Support for Type Library Headers for MSVC
  * Produce JSON depsfiles from MSVC
  * Disable aarch64 build as the ubuntu repo is failing
  * version 0.5.1
  * deps: Bump OpenDAL and reqsign (#1779)
  * fmt and clippy fixes
  * Opt in rather than opt out
  * Added env var to disable multi arch caching
  * Use object for parsing archives, and handle macOS fat archives
  * feat: Enable backtrace for anyhow (#1774)
* Wed May 24 2023 william.brown@suse.com
- Update to version 0.4.2~17:
  * Add experimental concurrent cache support
  * Exit when increment_compilation is enabled. (#1767)
  * version 0.5.0
  * fix grammar in GHA.md (#1765)
  * build(deps): bump uuid from 1.3.0 to 1.3.1
  * docs(gcs): mention external accounts
  * chore: bump `opendal` to `0.34.0`
  * Use Infallible instead of void (#1761)
  * Remove parity-tokio-ipc (#1759)
  * Replace lazy_static with once_cell (#1758)
  * Run fmt on compiler.rs
  * Add comments explaining why we need this change.
  * Fix clippy latest issues found by CI
  * Fix build issues found by CI with other compiler versions
  * Fix clippy issues found by CI
  * nvcc: Handle compiler detection when gcc isn't on the path
* Wed May 24 2023 William Brown <william.brown@suse.com>
- Update vendored dependencies
* Thu Apr 27 2023 william.brown@suse.com
- Update to version 0.4.2~2:
  * Add experimental concurrent cache support
  * nvcc: Correctly handle -ccbin argument given a directory
  * version 0.4.2
  * Improve the doc a bit
  * Add support for -Xclang -fno-pch-timestamp
  * Update to directories 5.0.0 and opendal 0.30.5 (#1716)
  * Make `SCCACHE_S3_NO_CREDENTIALS` require a value of `true` (#1724)
  * Add test for depfile flags for MSVC
  * Tests for /Fp and /Yc with MSVC
  * Add parsing for flags: Zm, Yc, sourceDependencies
  * fix: rust coverage test meets compile error for missing debuginfo (#1740)
  * Bump msrv to 1.65.0 (#1743)
  * use authentication in webdav test
  * Support authentication in WebDAV storage (#1608)
  * Update `Cargo.lock`
  * Disable trust-dns-resolver/dns-over-quic due to build failure on freeBSD
  * Update `Cargo.lock`
  * Use rustls for tls & trust-dns-resolver for dns resolution
  * build(deps): bump once_cell from 1.17.0 to 1.17.1
  * build(deps): bump async-trait from 0.1.66 to 0.1.68
  * snap: allow classic in snap review
  * snap: only do amd64
  * snap: fix description
  * snap: refer to why some arches are broken
  * snap: drop the daemon
  * ci: add snap workflows
  * snap: refresh snap for `base: core22`
  * build(deps): bump h2 from 0.3.15 to 0.3.17
  * Add test for response file with CR instead of CRLF
  * Fix Sccache Cannot Parse Response File that uses Carriage Returns Only on Windows #1726
  * When failing on startup, give more debug information Closes: #1717
* Thu Apr 13 2023 William Brown <william.brown@suse.com>
- bsc#1210346 - CVE-2023-26964 - hyper,h2: stream stacking when H2 processing HTTP2 RST_STREAM frames
* Tue Apr 11 2023 william.brown@suse.com
- Update to version 0.4.1~18:
  * Add experimental concurrent cache support
  * build(deps): bump chrono from 0.4.23 to 0.4.24
  * build(deps): bump serial_test from 1.0.0 to 2.0.0
  * Describe the default conf file locations in docs/Configuration.md
  * Remove unnecessary import
  * Use scoped thread provided by standard library (#1703)
  * Refactor import style (#1701)
  * Update rust-version in manifest to 1.64 (#1702)
  * Replace atty with is-terminal (#1699)
  * build(deps): bump clap from 4.0.32 to 4.1.11 (#1698)
  * Remove Redis TTL (#1696)
  * build(deps): bump assert_cmd from 2.0.8 to 2.0.10 (#1669)
  * build(deps): bump reqsign from 0.8.3 to 0.8.5 (#1692)
  * build(deps): bump reqwest from 0.11.15 to 0.11.16 (#1691)
  * build(deps): bump crossbeam-utils from 0.8.14 to 0.8.15 (#1693)
  * build(deps): bump toml from 0.7.2 to 0.7.3 (#1695)
  * build(deps): bump predicates from 2.1.5 to 3.0.2 (#1694)
  * build(deps): bump regex from 1.7.1 to 1.7.3 (#1690)
  * version 0.4.1
  * Revert "Support running dist compilations in unprivileged scenarios (#128)"
  * Revert "amend to sccache"
  * Revert "remove remainder cachepot and replace by sccache"
  * Revert "migrate to ubuntu 22.04 for newly added ci check"
  * build(deps): bump reqwest from 0.11.14 to 0.11.15
  * build(deps): bump openssl from 0.10.45 to 0.10.48
  * chore: Add more debug log for gcs to help us diagnose
  * Add tests to verify that we work with cmake & autotools (#1678)
  * Try to test c++ support with both clang & gcc
  * remove trailing whitespaces
* Wed Mar 22 2023 william.brown@suse.com
- Update to version 0.4.0~7:
  * Add experimental concurrent cache support
  * build(deps): bump mime from 0.3.16 to 0.3.17
  * build(deps): bump futures from 0.3.26 to 0.3.27
  * build(deps): bump tokio from 1.25.0 to 1.26.0
  * add codecov.yml and set threshold to 0.2%%, prevent coverage getting worse
  * Bump MSRV to 1.64
  * update of the description
  * Version 0.4.0
  * build(deps): bump anyhow from 1.0.68 to 1.0.70
  * build(deps): bump tempfile from 3.3.0 to 3.4.0
  * build(deps): bump libc from 0.2.139 to 0.2.140
  * build(deps): bump serde from 1.0.152 to 1.0.155
  * version v0.4.0-pre.11
  * Link to the github action
  * always ignore a set of variables
  * migrate to ubuntu 22.04 for newly added ci check
  * remove remainder cachepot and replace by sccache
  * amend to sccache
  * Support running dist compilations in unprivileged scenarios (#128)
  * Support emit pch header
  * Add doc for feature vendored-openssl in README.md
  * Add doc for feature vendored-openssl
  * Update Cargo.lock
  * Add new feature `vendored-openssl`
  * Fixed ToC and added back Storage Options section
  * version v0.4.0-pre.10
  * Add msvc response file integration test
  * Update MSVC compiler flags
  * Implement Response File support in MSVC
  * build(deps): bump url from 2.3.0 to 2.3.1
  * build(deps): bump daemonize from 0.4.1 to 0.5.0
  * build(deps): bump serde_json from 1.0.93 to 1.0.94
  * build(deps): bump async-trait from 0.1.63 to 0.1.66
  * build(deps): bump jobserver from 0.1.25 to 0.1.26
  * Clarify docs about units of `SCCACHE_IDLE_TIMEOUT`
  * tag v0.4.0-pre.9
  * build(deps): bump http from 0.2.8 to 0.2.9
  * build(deps): bump zstd from 0.12.2+zstd.1.5.2 to 0.12.3+zstd.1.5.2
  * build(deps): bump filetime from 0.2.19 to 0.2.20
  * build(deps): bump uuid from 1.2.2 to 1.3.0
  * fix: Allow building with no default feature (#1632)
  * build(deps): bump reqsign from 0.8.2 to 0.8.3
  * build(deps): bump opendal from 0.27.0 to 0.27.1
  * build(deps): bump gzp from 0.11.1 to 0.11.3
  * chore: fix typo in readme
  * deps: Bump toml and base64 (#1619)
  * build(deps): bump reqwest from 0.11.13 to 0.11.14 (#1586)
  * build(deps): bump tokio from 1.24.1 to 1.25.0 (#1584)
  * build(deps): bump tokio-util from 0.7.4 to 0.7.7 (#1604)
  * tag v0.4.0-pre.8
  * build: Increase edition to 2021
  * fix: Disable connection pool to fix dist server feature (#1612)
  * Ignore RPM environment variables (#1613)
  * build(deps): bump hyper from 0.14.23 to 0.14.24
  * build(deps): bump zip from 0.6.3 to 0.6.4
  * use fs_err for sake of better io errors (#1616)
  * dist/cache: include paths in error contexts (#1611)
  * fix upload artifact (#1598)
  * build(deps): bump serde_json from 1.0.91 to 1.0.93 (#1605)
  * Document SCCACHE_IDLE_TIMEOUT=0 (#1610)
  * feat: Add Webdav (a.k.a HTTP Cache) support (#1597)
* Thu Feb 23 2023 William Brown <william.brown@suse.com>
- bsc#1208553 - CVE-2022-31394 - header list size may allow denial of service
* Mon Feb 13 2023 william.brown@suse.com
- Update to version 0.4.0-pre.7
  * Force concurrent disk cache by default
  * Add experimental concurrent cache support
  * Ignore RPM env vars by default
  * deps: Cleanup superfluous dependency (#1602)
  * build(deps): bump cc from 1.0.78 to 1.0.79 (#1583)
  * build(deps): bump futures from 0.3.25 to 0.3.26 (#1587)
  * prepare version 0.4.0-pre.7
  * feat: Bump OpenDAL and remove hyperx (#1591)
  * feat: Print sccache version for Server stats (#1580)
  * Support nvcc's `--threads` flag (#1571)
  * fix rustfmt
  * fix: clippy warnings
  * Support mvsvc flag external:anglebrackets
  * fix: Sccache dist tests broken after bump to tokio 1.21 and later
  * build(deps): bump which from 4.3.0 to 4.4.0
  * build(deps): bump toml from 0.5.10 to 0.5.11
  * build(deps): bump async-trait from 0.1.61 to 0.1.63
  * preserve the backtrace in case of crashes
  * build(deps): bump nix from 0.26.1 to 0.26.2
  * build(deps): bump serial_test from 0.10.0 to 1.0.0
  * build(deps): bump assert_cmd from 2.0.7 to 2.0.8
  * build(deps): bump wiremock from 0.5.16 to 0.5.17
  * build(deps): bump zstd from 0.12.1+zstd.1.5.2 to 0.12.2+zstd.1.5.2
  * add a profile section
  * refactor: Migrate memcached to opendal based
  * prepare version 0.4.0-pre.6
  * Remove the author flag Many thanks to Ted and Alex for starting this project Now, many more people are authors too and the ownership can be seen in github already.
  * build(deps): bump regex from 1.7.0 to 1.7.1
  * Use eprintln instead of warn to avoid missing deprecated message
  * feat: Allow sccache keep running after hitting rate limit during check (#1557)
  * feat: Introduce the default gha version (#1550)
  * Add documentation for Cloudflare R2 usage. (#1549)
  * Fix remaining freebsd-ci problems (#1556)
  * feat: Take the whole rustc version into hash calculation (#1553)
  * Add support for clang '-fuse-ctor-homing' flag
  * refactor: Do read check first instead
  * build(deps): bump async-trait from 0.1.60 to 0.1.61
  * build(deps): bump clap from 4.0.29 to 4.0.32
  * Fix freebsd CI build (#1531)
  * prepare version 0.4.0-pre.5
  * refactor: Migrate gha cache to opendal based (#1528)
  * fix: handle -Xclang args when invoking clang/clang++ on windows cmake (#1500)
  * Remove the write
  * The "cache read miss" is now the compiler step. Make it more explicit
  * Rename the variable for something more explicit
  * prepare version 0.4.0-pre.4
  * build(deps): bump once_cell from 1.16.0 to 1.17.0
  * build(deps): bump num_cpus from 1.14.0 to 1.15.0
  * Make sure s3 check not passed
  * feat: Implement cache storage check
  * build(deps): bump predicates from 2.1.4 to 2.1.5
  * build(deps): bump wiremock from 0.5.15 to 0.5.16
  * fix(test): gcs check will fail if default features not enabled
  * Accept /fsanitize=address as a passthrough option for MSVC (#1518)
  * prepare version 0.4.0-pre.3
  * feat: Exit while cache is not configured correctly (#1515)
  * ci: Add integration tests for azblob (#1514)
  * ci: Add integration tests for s3 (#1513)
  * feat: Migrate redis to opendal based
  * ci: Refactor integration tests to make space for more services support (#1511)
  * ci: Add integration test for redis (#1510)
  * Bump async-trait from 0.1.59 to 0.1.60
  * Bump serde from 1.0.150 to 1.0.152
  * Bump futures-locks from 0.7.0 to 0.7.1
  * Bump cc from 1.0.77 to 1.0.78
  * Bump openssl from 0.10.44 to 0.10.45
  * Bump libc from 0.2.138 to 0.2.139
  * update of the version
  * feat: Enable logging for opendal operations
  * Re-enable `aarch64-unknown-linux-musl`
  * Fix duration attributed to cache writes in the log
  * feat: Add SCCACHE_GCS_CREDENTIALS_URL feature back for gcs
  * Bump serde_json from 1.0.89 to 1.0.91
  * Bump semver from 1.0.14 to 1.0.16
  * Bump anyhow from 1.0.66 to 1.0.68
  * Bump serial_test from 0.9.0 to 0.10.0
  * Bump toml from 0.5.9 to 0.5.10
  * Bump predicates from 2.1.2 to 2.1.4
  * Remove "Storage options" anchor link
  * github action: reverse the check
  * refresh cargo.lock
  * Fix the version
  * bump of the version
  * add version check
  * reorder the github config to have release last
  * Support FreeBSD as sccache-dist server (#1184)
  * Feature/847 allow caching multi arch builds (#1467)
  * deps: Bump base64 to 0.20 (#1477)
  * deps: move to clap 4 (#1476)
  * Bump zstd from 0.12.0+zstd.1.5.2 to 0.12.1+zstd.1.5.2
  * Bump openssl from 0.10.43 to 0.10.44
  * refactor: Migrate gcs cache to opendal based (#1474)
  * Bump jsonwebtoken from 8.1.1 to 8.2.0
  * Bump serde from 1.0.149 to 1.0.150
  * Bump filetime from 0.2.18 to 0.2.19
* Mon Dec 12 2022 william.brown@suse.com
- Update to version 0.3.3~20:
  * Fix azure deps
  * Force concurrent disk cache by default
  * Add experimental concurrent cache support
  * Ignore RPM env vars by default
  * Relax the assert_cmd dep - Closes: #1465 (#1466)
  * Update src/config.rs
  * Update src/config.rs
  * Fix typo
  * feat: Migrate azure to opendal based
  * Implement storage upon opendal Operator
  * Fix some typos
  * docs: move local into its own files
  * docs: move gha into its own files
  * docs: move azure into its own files
  * docs: move gcs into its own files
  * docs: move memcached into its own files
  * docs: move redis into its own files
  * docs: move s3 into its own files
  * docs: Enrich docs for s3 services
  * refactor: Integrate with opendal for s3 (#1412)
  * Disable the aarch64-unknown-linux-musl task for now Closes: #1458
  * update of the version
  * Remove bash dependency in test scripts
  * enable gha actions storage for the default feature set
  * Bump assert_cmd from 2.0.6 to 2.0.7
  * Bump env_logger from 0.9.3 to 0.10.0
  * Bump nix from 0.25.0 to 0.26.1
  * Bump serde from 1.0.148 to 1.0.149
  * Bump libc from 0.2.137 to 0.2.138
  * Bump async-trait from 0.1.58 to 0.1.59
  * Revert changes to cargo toml
  * Update lockfile
  * Remove openssl dependency when enabling GCS
  * Add configurable server timeout
  * fix https://github.com/mozilla/sccache/issues/1437
  * better support for toolchains with symlinks
  * remove unused aws-types
  * Remove unused sha-1 from dependencies
  * Update README.md to explain GHA cache behavior
  * Revert "handle symlinks when hashing the toolchain"
  * Revert "server: canonicalize path for compiler_info cache"
  * Revert "add tests for symlinks"
  * Revert "fix `invalid character in crate name` in test_symlinks"
  * Revert "fix --stop-server in test_symlinks"
  * Revert "fix test_symlinks when rustup is in PATH"
  * Revert "fix compatibility with bash 3 / macos 11 ci"
  * Bump assert_cmd from 2.0.5 to 2.0.6
  * Document the sccache process
  * Bump predicates from 2.1.1 to 2.1.2
  * Bump chrono from 0.4.22 to 0.4.23
  * Revert Cargo.lock
  * Update gha-toolkit and docs
  * Add support for GitHub Actions cache
  * Bump sha-1 from 0.10.0 to 0.10.1
  * Bump serde from 1.0.147 to 1.0.148
  * Update winapi
  * Update .github/dependabot.yml
  * Update .github/dependabot.yml
  * Update dependabot.yml
  * Reduce depandapot PR frequency
  * cargo update -p rouille
  * cargo update some indirect dependencies
  * Lower the ubuntu-18.04 version
  * Require openssl >= 0.10.9
  * adjust the CI to use 1.60
  * Fix a chrono warning:
  * update to Rust 1.60 as minimal version
  * Bump crossbeam-utils from 0.8.12 to 0.8.14
  * Revert "add cargo-deny configuration"
  * Revert "move from sha-1 (unmaintained) => sha1"
  * Revert "run cargo-deny in the ci"
  * run cargo-deny in the ci
  * move from sha-1 (unmaintained) => sha1
  * add cargo-deny configuration
  * Bump zstd from 0.11.2+zstd.1.5.2 to 0.12.0+zstd.1.5.2
  * Enable connection reuse in s3 client
  * Bump cc from 1.0.76 to 1.0.77
  * readme: remove `#` from shields.io url
  * Some minor github updates (#1401)
  * fix compatibility with bash 3 / macos 11 ci
  * fix test_symlinks when rustup is in PATH
  * fix --stop-server in test_symlinks
  * fix `invalid character in crate name` in test_symlinks
  * add tests for symlinks
  * server: canonicalize path for compiler_info cache
  * handle symlinks when hashing the toolchain
  * Improve the doc
  * Make `SCCACHE_S3_USE_SSL` optional
  * Bring back `SCCACHE_S3_USE_SSL`
  * Bump uuid from 1.2.1 to 1.2.2
  * Remove a strayed `cfg(feature = "s3")`
  * Set executable bit for binaries in release artifacts
  * Make s3 related tests sequential
  * Minimize Cargo.lock changes
  * Add some tests for s3
  * Update aws-* crates to latest version
  * New S3 backend
* Mon Nov 14 2022 william.brown@suse.com
- Update to version 0.3.1~3:
  * Force concurrent disk cache by default
  * Add experimental concurrent cache support
  * Ignore RPM env vars by default
  * Revert "test: add a test for bc"
  * Revert "add .bc as C++ extension"
  * with gcs: document the process
  * test: add a test for bc
  * test: add the support for extra args
  * Install gcc & clang for the test_sccache_command test
  * add .bc as C++ extension See: https://github.com/llvm/llvm-project/issues/58518#issuecomment-1312181006
* Mon Sep 26 2022 william.brown@suse.com
- Update to version 0.3.0~git5.14a4b8b:
  - improve disk cache performance
- Update of vendored dependencies
- bsc#1196972 - CVE-2022-24713 - Regex denial of service
- bsc#1194119 - CVE-2021-45710 - tokio data race with memory corruption
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Mon May 23 2022 william.brown@suse.com
- Update to version 0.3.0~git4.e5e233f:
  * Force concurrent disk cache by default
  * Ignore some env vars
  * Add experimental concurrent cache support
  * Increase the MSRV and bump dependencies (#1137)
- Remove 0001-Ignore-some-env-vars.patch as it is on the maint branch
* Wed May  4 2022 william.brown@suse.com
- Update to version 0.3.0~git0.f6e36e6:
  * (cargo-release) version 0.3.0
  * Rewrite dist client interface to uniformly use async (#1166)
  * Use clang -fminimize-whitespace to increase cache hits. (#1162)
  * Replace usages of blocking `reqwest` to be async instead (#1164)
  * Verify if a compile input is pure rlib or mixed rlib+staticlib before trimming (#1159)
  * Handle new 'rustc -Z ls' output lines (#1157)
  * Mark -std and -pedantic as pass-through flags for MSVC (#1151)
  * Ignore lockfiles of test crates used in the integration tests (#1149)
  * nvcc: support -ccbin / --compiler-bindir (#1147)
  * Revert "Automatically remove "awaiting response" label on-comment (#1129)" (#1142)
* Thu Apr 21 2022 William Brown <william.brown@suse.com>
- Change sources to zst compression
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Sun Mar 27 2022 William Brown <william.brown@suse.com>
- 0001-Ignore-some-env-vars.patch - sccache will ignore rebuilds if
  env vars change. As a result, we need to filter a number of values
  that rpm/osc-build injects that change frequently that disrupts
  the ability for sccache to cache effectively.
* Fri Mar 25 2022 William Brown <william.brown@suse.com>
- Ungate sccache from other arches
* Mon Mar 14 2022 william.brown@suse.com
- Update to resolve bsc#1196972 CVE-2022-24713 - Regex DOS
* Wed Mar  2 2022 william.brown@suse.com
- Update vendored dependencies
* Tue Feb 15 2022 william.brown@suse.com
- Update vendor.tar to resolve:
  * RUSTSEC-2021-0093: crossbeam-deque, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:H, class: ['memory-corruption']
  * RUSTSEC-2021-0020: hyper, cvss: CVSS:3.1/AV:N/AC:H/PR:N/UI:N/S:U/C:H/I:H/A:H, class: ['format-injection']
  * RUSTSEC-2021-0078: hyper, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:L/A:N, class: []
  * RUSTSEC-2021-0079: hyper, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:H/A:H, class: []
  * RUSTSEC-2021-0119: nix, cvss: None, class: ['memory-corruption']
  * RUSTSEC-2021-0003: smallvec, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:H, class: ['memory-corruption']
  * RUSTSEC-2021-0080: tar, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:H/A:N, class: []
  * RUSTSEC-2020-0031: tiny_http, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:L/I:L/A:N, class: []
  * RUSTSEC-2021-0124: tokio, cvss: None, class: ['memory-corruption', 'thread-safety']
  * RUSTSEC-2021-0124: tokio, cvss: None, class: ['memory-corruption', 'thread-safety']
* Thu Jan  6 2022 william.brown@suse.com
- resolve bsc#1194119 (CVE-2021-45710)
* Thu Dec 16 2021 wbrown@suse.de
- Update to version 0.2.15~git0.6b6d2f7:
  * (cargo-release) version 0.2.15
  * Update docs/Releasing.md
  * Workaround tiny_http issue #151 by disabling HTTP pipelining
  * Upgrade itertools to 0.10
  * Run `cargo update`
  * Add C compiler versions to the hash calculation when available
  * Move lru-disk-cache to an internal module
  * Fix clippy warnings in lru-disk-cache
  * Still read config file from Library/Preferences if it exists
  * Revert "Upgrade redis to 0.18"
* Thu Dec 16 2021 William Brown <william.brown@suse.com>
- Enable build on s390x, remove support for gcs which depends on ring.
* Fri Nov 26 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build also on armv6
* Tue Nov 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * sccache-dist-builder.service
  * sccache-dist-scheduler.service
* Wed Nov  3 2021 William Brown <william.brown@suse.com>
- Update license string in rpm
- Update vendor libraries
* Thu Oct 21 2021 William Brown <william.brown@suse.com>
- Extend supported arches for potential OBS usage
* Mon Oct 11 2021 wbrown@suse.de
- Set _service to use automatic vendor updates
- Set exclusive arches to match tier 1
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Change from rust-packaging to cargo-packaging
* Mon Jul  5 2021 William Brown <william.brown@suse.com>
- Update vendored dependencies to resolve
  - - potential memory corruption ( RUSTSEC-2021-0003 )
  - - potential format injection ( RUSTSEC-2021-0020 )
  - - potential request smuggling ( RUSTSEC-2020-0031 )
* Tue Jun 22 2021 William Brown <william.brown@suse.com>
- Allow extra architectures with sccache
* Wed Jan 13 2021 wbrown@suse.de
- Update to version 0.2.15~git1.22a176c:
  * (cargo-release) start next development iteration 0.2.16-alpha.0
  * (cargo-release) version 0.2.15
  * Update docs/Releasing.md
  * Workaround tiny_http issue #151 by disabling HTTP pipelining
  * Upgrade itertools to 0.10
  * Run `cargo update`
  * Add C compiler versions to the hash calculation when available
  * Move lru-disk-cache to an internal module
  * Fix clippy warnings in lru-disk-cache
  * Still read config file from Library/Preferences if it exists
* Tue Dec 22 2020 wbrown@suse.de
- Update to version 0.2.14~git0.655ef1a:
  * (cargo-release) version 0.2.14
  * Remove [patch] section for the purpose of release
  * Upgrade zstd to 0.6
  * Run `cargo update`
  * Bump lru-disk-cache version
  * Fix a few more clippy warnings
  * Make lru_disk_cache::Error's impl Display match what it was before 65bb3b6
  * Ignore both -FS and -MP on MSVC
  * Use a full path relative to `cwd` for extra hash files
  * Set the current directory of the server to the directory containing the executable
* Wed Nov 25 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on non-x86_64 archs
* Fri Nov 20 2020 William Brown <william.brown@suse.com>
- Fix service file commit definition
- Correct spec file example install
* Thu Nov 19 2020 wbrown@suse.de
- Update to version 0.2.13~git474.6628e1f:
  * New entry in ServerStartup enum to indicate AddrInUse Error (#840)
  * Revert "Bump to tiny-http 0.7.0 (#830)" because it caused a regression, #846.
  * Include -fsanitizer-blacklist in common_args
  * Consume sanitizer blacklist as extra hash in msvc (#842)
  * In case we fail to read the compressed content from the cache, treat the failure as a forced
    recache. This prevents us from failing build jobs unconditionally if cache entries are corrupt
    (or in case of other sporadic failures), in which case we should continue on with
    force-recompiling and recaching. (#836)
  * Bump to tiny-http 0.7.0 (#830)
  * Modify logging to use SCCACHE_LOG. (#822)
  * Implement `g++` and `clang++` behavior when used on a `.c` input file. Fixes #803 (#818)
  * clang: Allow chrome plugin arguments (#817)
  * Add known caveats section to readme (#815)
* Wed Nov 18 2020 William Brown <william.brown@suse.com>
- Configure features to generate sccache-dist for distributed builds.
- Add systemd unit files for builder and scheduler and example configs.
* Wed Nov 18 2020 William Brown <william.brown@suse.com>
- Add --features=all to allow all cache backends to be used.
* Tue Nov 17 2020 William Brown <william.brown@suse.com>
- Add support for obs cargo vendor to make packaging easier.
  * osc service ra - now can update the source files.
- Improvements to spec file.
- Fix invalid license string.
* Fri May 22 2020 Sumit Jamgade <sjamgade@suse.com>
- Initial Package
